@@ -10,4 +10,4 @@ class EchoMode(BaseMode):
     yield f'# {text}'
 
   def stats(self):
-    return '( location="cavern" )'
+    return '( location="chamber" )'
